==> apache-geode-1.13.8-src.tgz: apache-geode-1.13.8-src/geode-core/src/main/java/org/apache/geode/admin/internal/SystemMemberCacheEventImpl.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more contributor license
 * agreements. See the NOTICE file distributed with this work for additional information regarding
 * copyright ownership. The ASF licenses this file to You under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance with the License. You may obtain a
 * copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License
 * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing permissions and limitations under
 * the License.
 */
package org.apache.geode.admin.internal;

import org.apache.geode.admin.SystemMemberCacheEvent;
import org.apache.geode.admin.SystemMemberCacheListener;
import org.apache.geode.cache.Operation;
import org.apache.geode.distributed.DistributedMember;

/**
 * An event that describes an operation on a cache. Instances of this are delivered to a
 * {@link SystemMemberCacheListener} when a a cache is created or closed.
 *
 * @since GemFire 5.0
 */
public class SystemMemberCacheEventImpl extends SystemMembershipEventImpl
    implements SystemMemberCacheEvent {

  /** The operation done by this event */
  private Operation op;

  /////////////////////// Constructors ///////////////////////

  /**
   * Creates a new <code>SystemMemberCacheEvent</code> for the member with the given id.
   */
  protected SystemMemberCacheEventImpl(DistributedMember id, Operation op) {
    super(id);
    this.op = op;
  }

  ///////////////////// Instance Methods /////////////////////

  @Override
  public Operation getOperation() {
    return this.op;
  }

  @Override
  public String toString() {
    return super.toString() + " op=" + this.op;
  }

}

==> apache-geode-1.15.2-src.tgz: apache-geode-1.15.2-src/geode-core/src/main/java/org/apache/geode/admin/internal/SystemMemberCacheEventImpl.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more contributor license
 * agreements. See the NOTICE file distributed with this work for additional information regarding
 * copyright ownership. The ASF licenses this file to You under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance with the License. You may obtain a
 * copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License
 * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing permissions and limitations under
 * the License.
 */
package org.apache.geode.admin.internal;

import org.apache.geode.admin.SystemMemberCacheEvent;
import org.apache.geode.admin.SystemMemberCacheListener;
import org.apache.geode.cache.Operation;
import org.apache.geode.distributed.DistributedMember;

/**
 * An event that describes an operation on a cache. Instances of this are delivered to a
 * {@link SystemMemberCacheListener} when a a cache is created or closed.
 *
 * @since GemFire 5.0
 */
@Deprecated
public class SystemMemberCacheEventImpl extends SystemMembershipEventImpl
    implements SystemMemberCacheEvent {

  /** The operation done by this event */
  private final Operation op;

  /////////////////////// Constructors ///////////////////////

  /**
   * Creates a new <code>SystemMemberCacheEvent</code> for the member with the given id.
   */
  protected SystemMemberCacheEventImpl(DistributedMember id, Operation op) {
    super(id);
    this.op = op;
  }

  ///////////////////// Instance Methods /////////////////////

  @Override
  public Operation getOperation() {
    return op;
  }

  @Override
  public String toString() {
    return super.toString() + " op=" + op;
  }

}
